@@ -179,28 +179,29 @@ public class test {
 		}
 		
 		{ /* NAs in character vectors are mapped to null references in String[] and vice versa. Only Rserve 0.6-2 and later support NAa in character vectors. */
-			System.out.println("* Test handling of NAs in character vectors ('foo', NA, 'NA')");
+		  /* repression test: assigning empty string '' has failed in previous versions of RserveEngine */
+			System.out.println("* Test handling of NAs in character vectors ('foo', '', NA, 'NA')");
 			System.out.print("  push String[] with NAs: ");
-			eng.assign("s", new String[] { "foo", null, "NA" });
+			eng.assign("s", new String[] { "foo", "", null, "NA" });
 			int nas[] = eng.parseAndEval("is.na(s)").asIntegers();
 			for (int i = 0; i < nas.length; i++) System.out.print(nas[i] + " ");
-			if (nas.length != 3 || nas[0] != REXPLogical.FALSE || nas[1] != REXPLogical.TRUE || nas[2] != REXPLogical.FALSE)
-				throw new TestException("assigning null Strings as NAs has failed");
+			if (nas.length != 4 || nas[0] != REXPLogical.FALSE || nas[1] != REXPLogical.FALSE || nas[2] != REXPLogical.TRUE || nas[3] != REXPLogical.FALSE)
+				throw new TestException("assigning null Strings as NAs and '' has failed");
 			System.out.println(" - OK");
 			System.out.print("  pull String[] with NAs: ");
-			String s[] = eng.parseAndEval("c('foo', NA, 'NA')").asStrings();
-			for (int i = 0; i < s.length; i++) System.out.print(s[i] + " ");
-			if (s.length != 3 || s[0] == null || s[1] != null || s[2] == null)
-				throw new TestException("pulling Strings containin NAs has failed");
+			String s[] = eng.parseAndEval("c('foo', '', NA, 'NA')").asStrings();
+			for (int i = 0; i < s.length; i++) System.out.print("'" + s[i] + "' ");
+			if (s.length != 4 || s[0] == null || s[1] == null || !s[1].equals("") || s[2] != null || s[3] == null)
+				throw new TestException("pulling Strings containin NAs and '' has failed");
 			System.out.println(" - OK");
 			System.out.print("  compare pushed and constructed strings: ");
-			if (eng.parseAndEval("identical(s, c('foo', NA, 'NA'))").asInteger() != REXPLogical.TRUE)
-				throw new TestException("comparing Strings with NAs has failed");
+			if (eng.parseAndEval("identical(s, c('foo', '', NA, 'NA'))").asInteger() != REXPLogical.TRUE)
+				throw new TestException("comparing Strings with NAs and '' has failed");
 			System.out.println(" - OK");
-			System.out.print("  check isNA() for REXPString");
+			System.out.print("  check isNA() for REXPString:");
 			boolean na[] = eng.parseAndEval("s").isNA();
 			for (int i = 0; i < na.length; i++) System.out.print(" " + na[i]);
-			if (na.length != 3 || na[0] || !na[1] || na[2])
+			if (na.length != 4 || na[0] || na[1] || !na[2] || na[3])
 				throw new TestException("isNA() test failed");
 			System.out.println(" - OK");
 			System.out.println("PASSED");
